==> nifi-2.2.0-source-release.zip: nifi-2.2.0/nifi-frontend/src/main/frontend/apps/update-attribute/src/app/pages/update-attribute/ui/ua-editor/ua-editor.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { UaEditor } from './ua-editor.component';
import { HttpClientTestingModule } from '@angular/common/http/testing';
import { MockComponent } from 'ng-mocks';
import { PropertyHint } from '@nifi/shared';

import 'codemirror/addon/hint/show-hint';

describe('UaEditor', () => {
    let component: UaEditor;
    let fixture: ComponentFixture<UaEditor>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            imports: [UaEditor, HttpClientTestingModule, MockComponent(PropertyHint)]
        });
        fixture = TestBed.createComponent(UaEditor);
        component = fixture.componentInstance;
    });

    it('should create', () => {
        fixture.detectChanges();
        expect(component).toBeTruthy();
    });
});

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/update-attribute/src/app/pages/update-attribute/ui/ua-editor/ua-editor.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';
import { UaEditor } from './ua-editor.component';
import { CodemirrorNifiLanguageService, Codemirror } from '@nifi/shared';
import { PropertyHint } from '@nifi/shared';
import { MockComponent } from 'ng-mocks';

describe('UaEditor', () => {
    let component: UaEditor;
    let fixture: ComponentFixture<UaEditor>;

    beforeEach(async () => {
        await TestBed.configureTestingModule({
            imports: [UaEditor, MockComponent(Codemirror), MockComponent(PropertyHint)],
            providers: [
                {
                    provide: CodemirrorNifiLanguageService,
                    useValue: {
                        setLanguageOptions: () => {},
                        getLanguageSupport: () => ({})
                    }
                }
            ]
        }).compileComponents();

        fixture = TestBed.createComponent(UaEditor);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});
